##  Accessing Linked Items across SAP LeanIX and SAP Signavio
You can quickly access linked SAP Signavio items directly from the fact sheets in SAP LeanIX. This allows you to easily reference related information while working in SAP LeanIX. To access the linked item, on the right-side panel, click on Signavio under the Reference Catalog & Integrations section.
![Accessing Linked SAP Signavio Item From SAP LeanIX Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a18257a441014bed2cc18f7b1ab17_LowRes.png)
Accessing Linked SAP Signavio Item From SAP LeanIX Fact Sheet
Similarly, from within SAP Signavio, you can access linked SAP LeanIX fact sheets by clicking LeanIX Fact Sheet in the Relevant Documents section.
